macro_rules! setup {
($backend:expr, |$conn:ident| $body:expr) => { ... };
}Expand description
A macro to simplify setting up a database
This macro provides a cleaner API for the setup phase without requiring manual boxing.
macro_rules! setup {
($backend:expr, |$conn:ident| $body:expr) => { ... };
}A macro to simplify setting up a database
This macro provides a cleaner API for the setup phase without requiring manual boxing.